@@ -1,17 +1,12 @@
 ## @namespace unogenerator.commons
 ## @brief Common code to odfpy and openpyxl wrappers
-from datetime import datetime
+from datetime import datetime, date
 from gettext import translation
 from pkg_resources import resource_filename
-from logging import info, ERROR, WARNING, INFO, DEBUG, CRITICAL, basicConfig, error, debug
-from odf.opendocument import  __version__ as __odfpy_version__
-from os import path
-from shutil import copyfile
-from subprocess import run, PIPE
-from tempfile import TemporaryDirectory
+from logging import info, ERROR, WARNING, INFO, DEBUG, CRITICAL, basicConfig, error
 from uno import createUnoStruct
 
-__version__ = '0.2.0'
+__version__ = '0.2.9999'
 __versiondatetime__=datetime(2021, 9, 29, 12, 44)
 __versiondate__=__versiondatetime__.date()
 
@@ -26,9 +21,9 @@ class ColorsNamed:
     White=0xFFFFFF
     Blue=0x9999ff
     Red=0xFF9999
-    Green=0x99FF99
-    Orange=0xffd573
-    Yellow=0xffff7f
+    Green=0xc0FFc0
+    Orange=0xffdca8
+    Yellow=0xffffc0
     GrayLight=0xd2ced4
     GrayDark=0xa29ea4
     GrayVeryDark=0x726e74
@@ -115,8 +110,9 @@ def index2column(index):
 class Coord:
     def __init__(self, strcoord):
         self.letter, self.number=self.__extract(strcoord)
+
     def __repr__(self):
-        return "Coord <{}>".format(self.string())
+        return self.string()
 
     def __eq__(self, b):
         b=Coord.assertCoord(b)
@@ -216,7 +212,7 @@ class Range:
         self.start, self.end=self.__extract(strrange)
         
     def __repr__(self):
-        return "Range <{}>".format(self.string())
+        return self.string()
 
     ##Return the outcome of the test b in a. Note the reversed operands.
     def __contains__(self, b):
@@ -373,7 +369,7 @@ def guess_object_style(o):
     elif o.__class__.__name__=="int":
         return "Integer"
     elif o.__class__.__name__=="str":
-        return "Left"
+        return "Normal"
     elif o.__class__.__name__ in ["Currency", "Money" ]:
         return o.currency
     elif o.__class__.__name__=="Percentage":
@@ -391,3 +387,15 @@ def guess_object_style(o):
     else:
         info("guess_object_style not guessed {}".format( o.__class__))
         return "Bold"
+        
+def datetime2localc1989(o):
+    delta = o -  datetime(1899, 12, 30)
+    return float(delta.days) + float(delta.seconds) / 86400
+    
+def date2localc1989(o):
+    delta = o -  date(1899, 12, 30)
+    return float(delta.days) 
+
+def time2localc1989(o):
+    seconds=o.hour*3600+o.minute*60+o.second
+    return float(seconds) / 86400
